"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateDescribeLoadBalancers = void 0;
const AutoScalingClient_1 = require("../AutoScalingClient");
const DescribeLoadBalancersCommand_1 = require("../commands/DescribeLoadBalancersCommand");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new DescribeLoadBalancersCommand_1.DescribeLoadBalancersCommand(input), ...args);
};
async function* paginateDescribeLoadBalancers(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxRecords"] = config.pageSize;
        if (config.client instanceof AutoScalingClient_1.AutoScalingClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected AutoScaling | AutoScalingClient");
        }
        yield page;
        const prevToken = token;
        token = page.NextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateDescribeLoadBalancers = paginateDescribeLoadBalancers;
